@@ -3,7 +3,7 @@ package File::Find::Object::DeepPath;
 use strict;
 use warnings;
 
-our $VERSION = '0.3.0';
+our $VERSION = 'v0.3.1';
 
 use 5.008;
 
@@ -24,7 +24,7 @@ sub new {
     my $find = { %{$from->_inodes()} };
     if (my $inode = $self->_inode) {
         $find->{join(",", $self->_dev(), $inode)} =
-            scalar(@{$top->_dir_stack()});
+            $#{$top->_dir_stack()};
     }
     $self->_set_inodes($find);
 
@@ -631,7 +631,7 @@ File::Find::Object - An object oriented File::Find replacement
 
 =head1 VERSION
 
-version 0.3.0
+version v0.3.1
 
 =head1 SYNOPSIS
 
